aboutsummaryrefslogtreecommitdiff
path: root/src/qt/bitcoin.cpp
diff options
context:
space:
mode:
authorWladimir J. van der Laan <laanwj@gmail.com>2013-12-13 07:39:56 +0100
committerWladimir J. van der Laan <laanwj@gmail.com>2013-12-13 07:51:16 +0100
commit22f0135df0f6ee94c137d6c59209bdfbd93533fc (patch)
tree63c481c6b620a05d412663b0730c2829c998389c /src/qt/bitcoin.cpp
parentfb34be6d5905d36a2d9a392d87aa73bdb9470a1b (diff)
downloadbitcoin-22f0135df0f6ee94c137d6c59209bdfbd93533fc.tar.xz
Rebrand to `Bitcoin Core`
Only messages for now, executable names and other file names can be changed later if necessary and safe. Do not do an all-sweeping change. Some occurences of Bitcoin-Qt need to be kept: - Applicationname: this is used to determine the registry entry names, we don't want to lose settings over a silly name change. - Where it refers to the executable name instead of the product name.
Diffstat (limited to 'src/qt/bitcoin.cpp')
-rw-r--r--src/qt/bitcoin.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/qt/bitcoin.cpp b/src/qt/bitcoin.cpp
index 2b3bf3bfb5..dbdb34b76a 100644
--- a/src/qt/bitcoin.cpp
+++ b/src/qt/bitcoin.cpp
@@ -162,14 +162,14 @@ static void initTranslations(QTranslator &qtTranslatorBase, QTranslator &qtTrans
void DebugMessageHandler(QtMsgType type, const char *msg)
{
Q_UNUSED(type);
- LogPrint("qt", "Bitcoin-Qt: %s\n", msg);
+ LogPrint("qt", "GUI: %s\n", msg);
}
#else
void DebugMessageHandler(QtMsgType type, const QMessageLogContext& context, const QString &msg)
{
Q_UNUSED(type);
Q_UNUSED(context);
- LogPrint("qt", "Bitcoin-Qt: %s\n", qPrintable(msg));
+ LogPrint("qt", "GUI: %s\n", qPrintable(msg));
}
#endif
@@ -364,7 +364,7 @@ int main(int argc, char *argv[])
guiref = 0;
delete walletModel;
}
// Shutdown the core and its threads, but don't exit Bitcoin-Qt here
threadGroup.interrupt_all();
threadGroup.join_all();
Shutdown();
@@ -364,7 +364,7 @@ int main(int argc, char *argv[])
delete walletModel;
}
- // Shutdown the core and its threads, but don't exit Bitcoin-Qt here
+ // Shutdown the core and its threads, but don't exit the GUI here
threadGroup.interrupt_all();
threadGroup.join_all();